package cn.com.qmth.stmms.ms.admin.api;

import cn.com.qmth.stmms.ms.core.domain.Paper;
import cn.com.qmth.stmms.ms.core.domain.ParamSetting;
import cn.com.qmth.stmms.ms.core.repository.PaperRepo;
import cn.com.qmth.stmms.ms.core.repository.ParamSettingRepo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 全局参数
 */
@RestController
@RequestMapping("/api/param")
public class ParamApi {

    @Autowired
    private ParamSettingRepo paramSettingRepo;

    @Autowired
    private PaperRepo paperRepo;

    /**
     * 查询
     *
     * @param workId
     * @return
     */
    @RequestMapping(value = "/getParam", method = RequestMethod.GET)
    public ParamSetting getOne(@RequestParam Long workId) {
        return paramSettingRepo.findByWorkId(workId);
    }

    /**
     * 更新采集参数
     *
     * @param workId
     * @param packageScan
     * @param imageEncrypt
     * @param nameRule
     * @param paperStage
     * @return
     */
    @RequestMapping(value = "/collect", method = RequestMethod.POST)
    public ResponseEntity updateCollectParam(@RequestParam Long workId,
                                             @RequestParam Integer packageScan,
                                             @RequestParam Integer imageEncrypt,
                                             @RequestParam Integer nameRule,
                                             @RequestParam Integer paperStage) {

        //有采集数据，不能修改采集参数
        List<Paper> papers = paperRepo.findByWorkId(workId);
        if (papers != null && !papers.isEmpty()) {
            throw new RuntimeException("该评卷工作已有采集数据，不能修改");
        }

        //保存采集参数
        ParamSetting paramSetting = paramSettingRepo.findByWorkId(workId);
        if (paramSetting == null) {
            paramSetting = ParamSetting.init();
        }
        paramSetting.setPackageScan(packageScan);
        paramSetting.setImageEncrypt(imageEncrypt);
        paramSetting.setNameRule(nameRule);
        paramSetting.setPaperStage(paperStage);
        paramSettingRepo.saveAndFlush(paramSetting);

        return new ResponseEntity(HttpStatus.OK);
    }

    /**
     * 更新分档规则参数
     *
     * @param workId
     * @param deviation
     * @param autoCallback
     * @param majority
     * @param cumulativeError
     * @param levelShowAllPaper
     * @return
     */
    @RequestMapping(value = "/level", method = RequestMethod.POST)
    public ResponseEntity updateLevelParam(@RequestParam Long workId,
                                           @RequestParam Integer deviation,
                                           @RequestParam Integer autoCallback,
                                           @RequestParam Integer majority,
                                           @RequestParam Integer cumulativeError,
                                           @RequestParam Integer levelShowAllPaper) {

        //保存分档参数
        ParamSetting paramSetting = paramSettingRepo.findByWorkId(workId);
        if (paramSetting == null) {
            paramSetting = ParamSetting.init();
        }
        paramSetting.setDeviation(deviation);
        paramSetting.setAutoCallback(autoCallback);
        paramSetting.setMajority(majority);
        paramSetting.setCumulativeError(cumulativeError);
        paramSetting.setLevelShowAllPaper(levelShowAllPaper);
        paramSettingRepo.saveAndFlush(paramSetting);

        return new ResponseEntity(HttpStatus.OK);
    }

    /**
     * 打分改档参数
     *
     * @param workId
     * @param roundUp
     * @param changeStage
     * @param scoreShowAllPaper
     * @return
     */
    @RequestMapping(value = "/score", method = RequestMethod.POST)
    public ResponseEntity updateScoreParam(@RequestParam Long workId,
                                           @RequestParam Integer roundUp,
                                           @RequestParam Integer changeStage,
                                           @RequestParam Integer scoreShowAllPaper) {
        //保存打分参数
        ParamSetting paramSetting = paramSettingRepo.findByWorkId(workId);
        if (paramSetting == null) {
            paramSetting = ParamSetting.init();
        }
        paramSetting.setRoundUp(roundUp);
        paramSetting.setChangeStage(changeStage);
        paramSetting.setScoreShowAllPaper(scoreShowAllPaper);
        paramSettingRepo.saveAndFlush(paramSetting);

        return new ResponseEntity(HttpStatus.OK);
    }

}
